@@ -5,11 +5,10 @@ from curl2swift.processing.get_response_json import get_response_json
 from curl2swift.processing.prepare_enum_cases import prepare_enum_cases
 from urllib.parse import urlparse
 import sys
-
-import clipboard
+import subprocess
 
 from curl2swift.utils.logger import logging
-from curl2swift.parsing.get_request_properties import get_request_properties
+from curl2swift.parsing.parse_context import parse_context
 
 ParsedContent = namedtuple('ParsedContent', ('\
     url,\
@@ -34,7 +33,8 @@ def get_curl():
     else:
         logging.info('--curl option not used')
         logging.info('Reading curl from clipboard')
-        curl = clipboard.paste()
+        curl = subprocess.Popen(['pbpaste']).communicate()[0]
+        curl = curl if curl else ''
 
     curl = curl.replace('--location', '')
     curl = curl.replace('-v', '')
@@ -62,12 +62,12 @@ def get_request_content(parser):
     TEST_CURL = "curl -i https://api.github.com/users/defunkt"
     try:
         logging.info('Parsing cURL')
-        context = get_request_properties(curl, parser)
+        context = parse_context(curl, parser)
     except:
         logging.error('Parsing failed (see usage above)')
         logging.info('Falling back to test cURL')
         curl = TEST_CURL
-        context = get_request_properties(TEST_CURL, parser)
+        context = parse_context(TEST_CURL, parser)
 
     logging.info('Transforming cURL to Python request object')
     path_param_rows = [] # NOTE: path params are not yet supported
